#
# spec file for package gnome-games
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-games
Version:        3.26.1.1
Release:        lp150.1.7
Summary:        Browse and play your games - all of them
License:        GPL-3.0
Group:          System/GUI/GNOME
Url:            https://wiki.gnome.org/Apps/Games
Source:         http://download.gnome.org/sources/gnome-games/3.26/%{name}-%{version}.tar.xz
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(grilo-0.3)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(retro-gtk-0.12)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(tracker-sparql-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Games is a GNOME application to browse your video games library and to easily pick and play a game from it.

%lang_package

%prep
%setup -q
chmod -x COPYING

%build
%configure \
    --disable-static
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file org.gnome.Games -r Game Amusement
%find_lang %{name}

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/%{name}
%{_datadir}/icons/HighContrast/
%{_datadir}/icons/hicolor/*/apps/org.gnome.Games*
%{_libdir}/%{name}/
%{_datadir}/appdata/org.gnome.Games.appdata.xml
%{_datadir}/applications/org.gnome.Games.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Games.gschema.xml

# splitting out a devel makes no sense at this moment
%{_includedir}/libgnome-games.h
%{_datadir}/vala/vapi/gnome-games.vapi

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1.1:
  + Updated translations.
- Drop tar scm service, upstream now have regular releases.
* Sat Sep 30 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Updated translations.
- Drop %%icon_theme_cache_*, %%icon_theme_cache_*
  and %%glib2_gsettings_schema_* post/postun macros: functionality
  now covered by file triggers.
* Mon Sep 11 2017 aplazas@suse.com
- Update to version 3.26.0:
  + playstation: Parse only the basename of the executable.
  + Updated translations.
* Mon Sep  4 2017 adrien.plazas@suse.com
- Update to version 3.25.92:
  + Allow users to use any of their gamepads with integrated games
    by configuring their gamepads against the de-facto standard
    one. This is implemented via a wizard in the preferences page
    (bgo#780754).
  + Updated translations.
- Add BuildRequires pkgconfig(librsvg-2.0), new dependency.
* Tue Jul 18 2017 adrien.plazas@suse.com
- Update to version 3.25.4:
  + The way the games collection is built has been completely
    reworked to replace the GameSource types generating Game
    objects from any way of the implementation's choice by the trio
    of UriSource, UriGameFactory and GameCollection. UriSource
    generate URIs from any way of the implementation's choice,
    UriGameFactory generate Game objects from URIs and
    GameCollection acting as a glue between the two. This new
    flexibility in the creation of the games collection helped to
    simplify the way many game types were defined and helped to
    introduce new game sources to the collection.
  + Game URIs can now be passed as command line arguments, allowing
    your game files to be opened with Games from your file manager.
    The game will be automatically started by doing so.
  + Add a "Add game files" button to the collection view, allowing
    you to add game files from the collection view to the
    collection.
  + Game resources passed via the command line or the "Add game
    files" button are stored in a database and restored when
    starting the application. This allows Games to see your games
    even if its game resources detection mechanisms failed.
  + Introduction of RetroSimpleType to replace many very similar
    plugins by this simple and easier to maintain generic
    implementation of the Libretro based game types.
  + Supported games:
  - Add support for Atari Lynx, MS-DOS, WonderSwan and WonderSwan
    Color games.
  - Improve the detection of PlayStation discs by parsing them as
    an emulator would instead of using lucky guessing the
    location of the required information in the disc.
  - Don't display desktop games setting the NoDisplay or Hidden
    keys.
  + Gamepad:
  - Port the gamepad handling system from Vala to C to avoid
    using Vala's preprocessor as it is poorly handled by the
    autotools, resulting in broken tarballs.
  - Make gamepads send events similar to GdkEvent.
  - Replace the custom input types by the Linux event codes.
  + UI:
  - Use the more appropriate GtkMessageDialog instead of
    GtkDialog for most of the existing custom dialogs.
  - Refine the look of MediaSelector, using checkmarks to denote
    the currently used media.
  - Use theme relative colors for the games collection.
  - Drop a useless sorting invalidation in CollectionIconView,
    which makes the game collection loads a bit faster.
  + Improved logging of the Libretro cores by using the Core.log()
    signal with the retro_g_log() function which have been
    introduced in retro-gtk recently. This will log messages from
    the Libretro core with the core's name as the log domain
    instead of GNOME Games.
  + Improve the parameters passed to the grep command to avoid
    injections.
  + Bump retro-gtk to 0.12.
  + Bump tracker-sparql to 2.0.
  + Updated translations.
- Add BuildRequires pkgconfig(sqlite3), new dependency.
- Replace pkgconfig(retro-gtk-0.10) with pkgconfig(retro-gtk-0.12)
  BuildRequires.
- Replace  pkgconfig(tracker-sparql-1.0) with
  pkgconfig(tracker-sparql-2.0) BuildRequires.
* Tue Apr 11 2017 adrien.plazas@suse.com
- Update to version 3.24.1:
  + Clean the licensing up all around the project (bgo#781036).
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0.2:
  + Distribute more files (bgo#780318).
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0.1:
  + Distribute the .gschema.xml.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Make distcheck produce .xz tarballs by default
  + Add the Flatpak build manifest for the PicoDrive extension
  + Add metadata to the produced screenshots
  + Bugs fixed: bgo#769833, bgo#779987.
  + Updated translations.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Add the Flatpak build manifest.
  + Look for Libretro cores recursively into directories.
  + Fix some typos.
  + Bugs fixed: bgo#779403, bgo#779780.
  + Updated translations.
- Drop _service: this is published as proper tarballs by upstream.
- Drop libtool BuildRequires and no longer call autogen.sh: the
  tarball is properly bootstrapped.
* Tue Feb 28 2017 adrien.plazas@suse.com
- Update to version 3.23.91:
  + Allow to have smooth or sharp video output on retro games.
  + Add more explicative error messages.
  + Remember the size of the application window.
  + Remember the maximized state of the application window.
  + Remember the fullscreen state of the retro games.
  + Prevent a useless empty button to be displayed on the error
    page.
  + Prevent keyboard shortcuts to set the window fullscreen when
    not allowed.
  + Fix keyboard navigation in the game collection.
  + Check the presence of mandatory firmwares.
  + List standalone Libretro games.
- Handle gschema files in post(un).
* Tue Feb 14 2017 adrien.plazas@suse.com
- Update to version 3.23.90:
  + Show a spinner notification when loading games.
  + Smooth out the collection icons arrangement.
  + Hide menubar when the app menu is disabled.
  + Check there is a media set before updating it.
  + Support Libretro cores having a Libretro Core Descriptor.
  + Auto-detect Libretro cores supporting serialization.
  + Be more tolerant with serialization sizes to follow Libretro
    rules.
  + Allow Libretro cores to load firmwares in
    ~/.config/gnome-games.
  + Add support for FDS games.
  + Avoid some valid Game Boy games to not be detected.
- Backwards-incompatible changes:
  + Drop support for the .info Libretro core descriptor format in
    favor of a new .libretro format.
  + Drop support for Libretro cores in $(libdir)/retro-1.0/plugins
    in favor of the ones in $(libdir)/libretro.
  + Drop support for Libretro core paths in the
    RETRO_PLUGIN_PATH_1_0 environment variable in favor of the ones
    in LIBRETRO_PLUGIN_PATH.
- Replace pkgconfig(retro-gobject-0.8) and pkgconfig(retro-gtk-0.8)
  BuildRequires with pkgconfig(retro-gtk-0.10).
* Wed Sep 21 2016 dimstar@opensuse.org
- Initial package, version 3.22.0.
